# HIVE CoinZdense Disaster Recovery tools

First do a pip install
```
python3 -m pip install hiveqdpr
```
If you still have your master password, call:
```
hqpdr-userpost-masterpass myhiveaccount
```
If instead you only have your owner key and your active key call:
```
hqpdr-userpost-randomkey myhiveaccount
```
